<img src="docs/img/logo_large.png" width="120" align="right">

[![pytest](https://github.com/ing-bank/probatus/workflows/Unit%20tests/badge.svg)](https://github.com/ing_rpaa/probatus/actions)
[![coverage report](https://gitlab.com/ing_rpaa/probatus/badges/master/coverage.svg)](https://gitlab.com/ing_rpaa/probatus/-/commits/master)
[![PyPi Version](https://img.shields.io/pypi/pyversions/probatus)](#)
[![PyPI](https://img.shields.io/pypi/v/probatus)](#)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/probatus)](#)

# Probatus

## Overview

**Probatus** is a Python library that allows to analyse binary classification models as well as the data used to develop them.
The main features assess the metric stability and analyse differences between two data samples e.g. shift between train and test splits.

## Installation

In order to install probatus you need to use Python 3.6 or higher.

You can install probatus using pip:

```bash
pip install probatus
```

Alternatively you can fork/clone and run:

```bash
git clone https://gitlab.com/ing_rpaa/probatus.git
cd probatus
pip install .
```

## Documentation

Documentation can be found [here](https://ing-bank.github.io/probatus/).

## Contribution

To learn more about making a contribution to probatus, please see [`CONTRIBUTING.md`](CONTRIBUTING.md).
